#!/usr/bin/env node
import { execSync } from "child_process";
import inquirer from "inquirer";

const presets = {
  shadeflow: [
    "@shadcn/ui",
    "tailwindcss",
    "react-router-dom",
    "@tanstack/react-query",
    "framer-motion",
    "react-hook-form",
    "zod",
    "clsx",
    "react-icons"
  ],
  materialwave: [
    "@mui/material",
    "@emotion/react",
    "tailwindcss",
    "react-router-dom",
    "zustand",
    "react-hook-form",
    "yup",
    "@tanstack/react-query",
    "react-icons"
  ],
  petalstack: [
    "daisyui",
    "tailwindcss",
    "react-router-dom",
    "zustand",
    "react-hook-form",
    "zod",
    "framer-motion",
    "react-icons"
  ],
  radixcore: [
    "@radix-ui/react-dropdown-menu",
    "tailwindcss",
    "react-router-dom",
    "zustand",
    "react-hook-form",
    "zod",
    "@tanstack/react-query",
    "clsx"
  ],
  chakraflow: [
    "@chakra-ui/react",
    "@emotion/react",
    "tailwindcss",
    "react-router-dom",
    "jotai",
    "react-hook-form",
    "zod",
    "swr",
    "clsx"
  ],
  stackforge: [
    "@shadcn/ui",
    "tailwindcss",
    "react-router-dom",
    "@tanstack/react-query",
    "react-hook-form",
    "zod",
    "prisma",
    "axios",
    "express"
  ]
};

const args = process.argv.slice(2);
const appName = args[0];
let presetArg = args[1];

async function run() {
  if (!appName) {
    console.log("❌ Please provide a project name");
    process.exit(1);
  }

  if (!presetArg) {
    const answer = await inquirer.prompt([
      {
        type: "list",
        name: "preset",
        message: "Pick a UI Stack:",
        choices: Object.keys(presets)
      }
    ]);
    presetArg = answer.preset;
  }

  const preset = presets[presetArg];
  if (!preset) {
    console.log(`❌ Invalid preset. Available: ${Object.keys(presets).join(", ")}`);
    process.exit(1);
  }

  console.log(`🚀 Creating project: ${appName}`);
  execSync(`npm create vite@latest ${appName} -- --template react`, { stdio: "inherit" });
  console.log(`✅ Installing dependencies for preset: ${presetArg}`);
  execSync(`cd ${appName} && npm install ${preset.join(" ")}`, { stdio: "inherit" });
  console.log("🎉 Done! Now run:");
  console.log(`cd ${appName}`);
  console.log(`npm run dev`);
}

run();
